@@ -4,13 +4,16 @@ from pyspark.sql import Column, DataFrame
 from pyspark.sql.functions import substring
 
 from spark_auto_mapper.data_types.text_like_base import AutoMapperTextLikeBase
-from spark_auto_mapper.type_definitions.wrapper_types import AutoMapperColumnOrColumnLikeType
+from spark_auto_mapper.type_definitions.wrapper_types import (
+    AutoMapperColumnOrColumnLikeType,
+)
 
 
 class AutoMapperSubstringDataType(AutoMapperTextLikeBase):
     """
     Finds a substring in a string
     """
+
     def __init__(
         self, column: AutoMapperColumnOrColumnLikeType, start: int, length: int
     ):
@@ -26,6 +29,8 @@ class AutoMapperSubstringDataType(AutoMapperTextLikeBase):
         column_spec = substring(
             self.column.get_column_spec(
                 source_df=source_df, current_column=current_column
-            ), self.start, self.length
+            ),
+            self.start,
+            self.length,
         )
         return column_spec
