@@ -1,6 +1,9 @@
 from typing import Any, Dict, Union, TypeVar, cast, Optional, List, Callable
 
+# noinspection PyPackageRequirements
 from pyspark.sql.types import StringType
+
+# noinspection PyPackageRequirements
 from pyspark.sql import Column
 
 from spark_auto_mapper.data_types.array_distinct import AutoMapperArrayDistinctDataType
@@ -13,6 +16,7 @@ from spark_auto_mapper.data_types.filter import AutoMapperFilterDataType
 from spark_auto_mapper.data_types.hash import AutoMapperHashDataType
 from spark_auto_mapper.data_types.if_ import AutoMapperIfDataType
 from spark_auto_mapper.data_types.if_not import AutoMapperIfNotDataType
+from spark_auto_mapper.data_types.unix_timestamp import AutoMapperUnixTimestampType
 from spark_auto_mapper.data_types.if_not_null_or_empty import (
     AutoMapperIfNotNullOrEmptyDataType,
 )
@@ -121,6 +125,15 @@ class AutoMapperHelpers:
 
         :param value: sql
         :return: an expression automapper type
+        :example: A.expression(
+                "
+                CASE
+                    WHEN `Member Sex` = 'F' THEN 'female'
+                    WHEN `Member Sex` = 'M' THEN 'male'
+                    ELSE 'other'
+                END
+                "
+                )
         """
         return AutoMapperDataTypeExpression(value)
 
@@ -700,3 +713,13 @@ class AutoMapperHelpers:
         :return: a join automapper type
         """
         return AutoMapperJoinUsingDelimiterDataType(column=column, delimiter=delimiter)
+
+    @staticmethod
+    def unix_timestamp(value: AutoMapperNumberInputType) -> AutoMapperUnixTimestampType:
+        """
+        Joins an array and forms a string using the delimiter
+
+        :param value: value to convert to unix timestamp
+        :return: a join automapper type
+        """
+        return AutoMapperUnixTimestampType(value=value)
