@@ -6,7 +6,6 @@ from pyspark.sql import SparkSession, Column, DataFrame
 from pyspark.sql.functions import col, lit
 
 from spark_auto_mapper.automappers.automapper import AutoMapper
-from spark_auto_mapper.expression_comparer import assert_expressions_are_equal
 from spark_auto_mapper.helpers.automapper_helpers import AutoMapperHelpers as A
 
 
@@ -38,11 +37,11 @@ def test_auto_mapper_boolean(spark_session: SparkSession) -> None:
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
-    assert_expressions_are_equal(
-        sql_expressions["age"], col("b.my_age").cast("boolean").alias("age")
+    assert str(sql_expressions["age"]) == str(
+        col("b.my_age").cast("boolean").alias("age")
     )
-    assert_expressions_are_equal(
-        sql_expressions["is_active"], lit("False").cast("boolean").alias("is_active")
+    assert str(sql_expressions["is_active"]) == str(
+        lit("False").cast("boolean").alias("is_active")
     )
 
     result_df: DataFrame = mapper.transform(df=df)
@@ -51,24 +50,12 @@ def test_auto_mapper_boolean(spark_session: SparkSession) -> None:
     result_df.printSchema()
     result_df.show()
 
-    assert (
-        result_df.where("member_id == 1")
-        .select(
-            "age",
-            "is_active",
-        )
-        .collect()[0][:]
-        == (False, False)
-    )
-    assert (
-        result_df.where("member_id == 2")
-        .select(
-            "age",
-            "is_active",
-        )
-        .collect()[0][:]
-        == (True, False)
-    )
+    assert result_df.where("member_id == 1").select("age", "is_active",).collect()[0][
+        :
+    ] == (False, False)
+    assert result_df.where("member_id == 2").select("age", "is_active",).collect()[0][
+        :
+    ] == (True, False)
 
     assert dict(result_df.dtypes)["age"] == "boolean"
     assert dict(result_df.dtypes)["is_active"] == "boolean"
